# Post-hospitalization Mortality Prediction

This sub-folder specifically captures predictions of mortality in some period after patient discharge (e.g.,
30-day mortality). This is a different task, both in construction and in terms of effective intervention
surface, than in-hospital mortality prediction. It can be a useful proxy both for the patient's general state
of health as of discharge but also in concert with readmission prediction tasks to appropriately differentiate
predictions of a patient being unlikely to be readmitted due to good health or due to the likely risk of
death.
